@@ -36,7 +36,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddResourceTag", params)
+            headers = request.headers
+            body = self.call("AddResourceTag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddResourceTagResponse()
@@ -64,7 +65,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AttachResourcesTag", params)
+            headers = request.headers
+            body = self.call("AttachResourcesTag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AttachResourcesTagResponse()
@@ -92,7 +94,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTag", params)
+            headers = request.headers
+            body = self.call("CreateTag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTagResponse()
@@ -120,7 +123,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTags", params)
+            headers = request.headers
+            body = self.call("CreateTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTagsResponse()
@@ -148,7 +152,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteResourceTag", params)
+            headers = request.headers
+            body = self.call("DeleteResourceTag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteResourceTagResponse()
@@ -176,7 +181,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTag", params)
+            headers = request.headers
+            body = self.call("DeleteTag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTagResponse()
@@ -204,7 +210,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteTags", params)
+            headers = request.headers
+            body = self.call("DeleteTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteTagsResponse()
@@ -222,6 +229,35 @@ class TagClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeProjects(self, request):
+        """获取项目列表
+
+        :param request: Request instance for DescribeProjects.
+        :type request: :class:`tencentcloud.tag.v20180813.models.DescribeProjectsRequest`
+        :rtype: :class:`tencentcloud.tag.v20180813.models.DescribeProjectsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeProjects", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeProjectsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeResourceTags(self, request):
         """查询资源关联标签
 
@@ -232,7 +268,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceTags", params)
+            headers = request.headers
+            body = self.call("DescribeResourceTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourceTagsResponse()
@@ -260,7 +297,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceTagsByResourceIds", params)
+            headers = request.headers
+            body = self.call("DescribeResourceTagsByResourceIds", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourceTagsByResourceIdsResponse()
@@ -288,7 +326,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceTagsByResourceIdsSeq", params)
+            headers = request.headers
+            body = self.call("DescribeResourceTagsByResourceIdsSeq", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourceTagsByResourceIdsSeqResponse()
@@ -316,7 +355,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceTagsByTagKeys", params)
+            headers = request.headers
+            body = self.call("DescribeResourceTagsByTagKeys", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourceTagsByTagKeysResponse()
@@ -344,7 +384,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourcesByTags", params)
+            headers = request.headers
+            body = self.call("DescribeResourcesByTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourcesByTagsResponse()
@@ -372,7 +413,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourcesByTagsUnion", params)
+            headers = request.headers
+            body = self.call("DescribeResourcesByTagsUnion", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourcesByTagsUnionResponse()
@@ -400,7 +442,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTagKeys", params)
+            headers = request.headers
+            body = self.call("DescribeTagKeys", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTagKeysResponse()
@@ -428,7 +471,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTagValues", params)
+            headers = request.headers
+            body = self.call("DescribeTagValues", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTagValuesResponse()
@@ -456,7 +500,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTagValuesSeq", params)
+            headers = request.headers
+            body = self.call("DescribeTagValuesSeq", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTagValuesSeqResponse()
@@ -484,7 +529,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTags", params)
+            headers = request.headers
+            body = self.call("DescribeTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTagsResponse()
@@ -512,7 +558,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTagsSeq", params)
+            headers = request.headers
+            body = self.call("DescribeTagsSeq", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTagsSeqResponse()
@@ -540,7 +587,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DetachResourcesTag", params)
+            headers = request.headers
+            body = self.call("DetachResourcesTag", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DetachResourcesTagResponse()
@@ -568,7 +616,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetResources", params)
+            headers = request.headers
+            body = self.call("GetResources", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetResourcesResponse()
@@ -596,7 +645,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetTagKeys", params)
+            headers = request.headers
+            body = self.call("GetTagKeys", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetTagKeysResponse()
@@ -624,7 +674,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetTagValues", params)
+            headers = request.headers
+            body = self.call("GetTagValues", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetTagValuesResponse()
@@ -652,7 +703,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetTags", params)
+            headers = request.headers
+            body = self.call("GetTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetTagsResponse()
@@ -680,7 +732,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyResourceTags", params)
+            headers = request.headers
+            body = self.call("ModifyResourceTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyResourceTagsResponse()
@@ -708,7 +761,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyResourcesTagValue", params)
+            headers = request.headers
+            body = self.call("ModifyResourcesTagValue", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyResourcesTagValueResponse()
@@ -736,7 +790,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TagResources", params)
+            headers = request.headers
+            body = self.call("TagResources", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TagResourcesResponse()
@@ -764,7 +819,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UnTagResources", params)
+            headers = request.headers
+            body = self.call("UnTagResources", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UnTagResourcesResponse()
@@ -792,7 +848,8 @@ class TagClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateResourceTagValue", params)
+            headers = request.headers
+            body = self.call("UpdateResourceTagValue", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateResourceTagValueResponse()
